#[repr(C, align(16))]pub struct BVec4A {
pub x: u32,
pub y: u32,
pub z: u32,
pub w: u32,
}Expand description
A 4-dimensional u32 vector mask.
Fields
x: u32y: u32z: u32w: u32Implementations
Sourceimpl BVec4A
impl BVec4A
Sourcepub const fn from_array(a: [bool; 4]) -> BVec4A
pub const fn from_array(a: [bool; 4]) -> BVec4A
Creates a new vector mask from a bool array.
Sourcepub fn bitmask(self) -> u32
pub fn bitmask(self) -> u32
Returns a bitmask with the lowest 4 bits set from the elements of self.
A true element results in a 1 bit and a false element in a 0 bit. Element x goes
into the first lowest bit, element y into the second, etc.