pub struct AnimationSystem;Expand description
Animation system.
Drives updates for all AnimationMixer components.
Implementations
Sourceimpl AnimationSystem
impl AnimationSystem
Sourcepub fn update<K>(
mixers: &mut SlotMap<K, AnimationMixer>,
target: &mut dyn AnimationTarget,
dt: f32,
)where
K: Key,
pub fn update<K>(
mixers: &mut SlotMap<K, AnimationMixer>,
target: &mut dyn AnimationTarget,
dt: f32,
)where
K: Key,
Updates all animation mixers against the given animation target.
The caller is responsible for extracting mixers from their storage before calling this method (to avoid borrow conflicts when the target and mixer storage share the same owner).
Arguments
mixers- All animation mixers to updatetarget- The animation target (e.g. scene graph) to apply results todt- Delta time per frame (in seconds)