pub struct Mesh {
pub name: String,
pub geometry: GeometryHandle,
pub material: MaterialHandle,
pub visible: bool,
pub cast_shadows: bool,
pub receive_shadows: bool,
pub render_order: i32,
/* private fields */
}Fields
name: Stringgeometry: GeometryHandlematerial: MaterialHandlevisible: boolcast_shadows: boolreceive_shadows: boolrender_order: i32Implementations
Sourceimpl Mesh
impl Mesh
pub fn new(geometry: GeometryHandle, material: MaterialHandle) -> Mesh
Sourcepub fn morph_target_influences(&self) -> &[f32]
pub fn morph_target_influences(&self) -> &[f32]
Returns the morph target influences as a slice
pub fn morph_uniforms(&self) -> BufferReadGuard<'_, MorphUniforms>
pub fn morph_uniforms_mut(&mut self) -> BufferGuard<'_, MorphUniforms>
Sourcepub fn init_morph_targets(&mut self, target_count: u32, vertex_count: u32)
pub fn init_morph_targets(&mut self, target_count: u32, vertex_count: u32)
initialize morph target influences should be called after loading geometry
Sourcepub fn latch_previous_morph_weights(&mut self)
pub fn latch_previous_morph_weights(&mut self)
Calls this at the end of each frame to latch current morph target influences into the “previous” cache.
Sourcepub fn set_morph_target_influence(&mut self, index: usize, weight: f32)
pub fn set_morph_target_influence(&mut self, index: usize, weight: f32)
set influence for a single morph target
Sourcepub fn set_morph_target_influences(&mut self, weights: &[f32])
pub fn set_morph_target_influences(&mut self, weights: &[f32])
batch set morph target influences
Sourcepub fn update_morph_uniforms(&mut self)
pub fn update_morph_uniforms(&mut self)
update Morph Uniforms (sort, cull, and fill GPU buffer) should be called before each frame rendering