pub struct ShaderDefines { /* private fields */ }Expand description
A collection of shader macro definitions.
Internally uses an ordered Vec<(Symbol, Symbol)> to store definitions,
ensuring that identical macro sets produce identical hash values.
Performance
- Insertion/lookup: O(log n) due to binary search
- Hash computation: O(n) but cached
- Comparison: O(1) when using cached hashes
Implementations
Sourceimpl ShaderDefines
impl ShaderDefines
Sourcepub fn new() -> ShaderDefines
pub fn new() -> ShaderDefines
Create empty shader defines collection
Sourcepub fn with_capacity(capacity: usize) -> ShaderDefines
pub fn with_capacity(capacity: usize) -> ShaderDefines
Create shader defines collection with pre-allocated capacity
Sourcepub fn set(&mut self, key: &str, value: &str)
pub fn set(&mut self, key: &str, value: &str)
Set shader define (maintains sorted order)
If key exists, updates its value; otherwise inserts new entry.
Sourcepub fn set_symbol(&mut self, key: Spur, value: Spur)
pub fn set_symbol(&mut self, key: Spur, value: Spur)
Set shader define using Symbol (internal method, more efficient)
Sourcepub fn remove_symbol(&mut self, key: Spur) -> bool
pub fn remove_symbol(&mut self, key: Spur) -> bool
Remove shader define using Symbol
Sourcepub fn contains_symbol(&self, key: Spur) -> bool
pub fn contains_symbol(&self, key: Spur) -> bool
Check if contains a shader define using Symbol
Sourcepub fn get_symbol(&self, key: Spur) -> Option<Cow<'static, str>>
pub fn get_symbol(&self, key: Spur) -> Option<Cow<'static, str>>
Get shader define value using Symbol
Sourcepub fn iter(&self) -> impl Iterator<Item = &(Spur, Spur)>
pub fn iter(&self) -> impl Iterator<Item = &(Spur, Spur)>
Iterate all shader defines (as Symbols)
Sourcepub fn iter_strings(&self) -> impl Iterator<Item = (String, String)>
pub fn iter_strings(&self) -> impl Iterator<Item = (String, String)>
Iterate all shader defines (as strings)
Sourcepub fn merge(&mut self, other: &ShaderDefines)
pub fn merge(&mut self, other: &ShaderDefines)
Merge shader defines from another ShaderDefines
If there are conflicts, values from other will override values in self.
Sourcepub fn merged_with(&self, other: &ShaderDefines) -> ShaderDefines
pub fn merged_with(&self, other: &ShaderDefines) -> ShaderDefines
Create a new merged ShaderDefines
Sourcepub fn compute_hash(&self) -> u64
pub fn compute_hash(&self) -> u64
Compute content hash (for caching)