#[repr(C, align(1))]pub struct BVec4 {
pub x: bool,
pub y: bool,
pub z: bool,
pub w: bool,
}Expand description
A 4-dimensional bool vector mask.
Fields
x: booly: boolz: boolw: boolImplementations
Sourceimpl BVec4
impl BVec4
Sourcepub const fn from_array(a: [bool; 4]) -> BVec4
pub const fn from_array(a: [bool; 4]) -> BVec4
Creates a new vector mask from a bool array.
Sourcepub fn bitmask(self) -> u32
pub fn bitmask(self) -> u32
Returns a bitmask with the lowest 4 bits set from the elements of self.
A true element results in a 1 bit and a false element in a 0 bit. Element x goes
into the first lowest bit, element y into the second, etc.