AnimationSystem

Struct AnimationSystem 

pub struct AnimationSystem;
Animation system.

Drives updates for all AnimationMixer components.

Implementations

Source

impl AnimationSystem

pub fn update<K>( mixers: &mut SlotMap<K, AnimationMixer>, target: &mut dyn AnimationTarget, dt: f32, )
where K: Key,

Updates all animation mixers against the given animation target.

The caller is responsible for extracting mixers from their storage before calling this method (to avoid borrow conflicts when the target and mixer storage share the same owner).

Arguments
  • mixers - All animation mixers to update
  • target - The animation target (e.g. scene graph) to apply results to
  • dt - Delta time per frame (in seconds)