pub struct App { /* private fields */ }Expand description
Application builder for configuring and launching the engine.
Implementations
Sourceimpl App
impl App
pub fn with_title(self, title: impl Into<String>) -> App
Sourcepub fn with_init_config(self, config: RendererInitConfig) -> App
pub fn with_init_config(self, config: RendererInitConfig) -> App
Sets the static GPU initialization configuration.
Sourcepub fn with_settings(self, settings: RendererSettings) -> App
pub fn with_settings(self, settings: RendererSettings) -> App
Sets the runtime rendering settings.
Sourcepub fn with_inner_size(self, width: u32, height: u32) -> App
pub fn with_inner_size(self, width: u32, height: u32) -> App
Sets the initial logical size of the window (only effective for native, WASM is controlled by CSS).
Sourcepub fn run<H>(self) -> Result<(), Error>where
H: AppHandler,
pub fn run<H>(self) -> Result<(), Error>where
H: AppHandler,
Runs the application with the specified handler.
This method blocks until the application exits. The event loop takes ownership of the current thread.
Type Parameters
H- The application handler type implementingAppHandler
Errors
Returns an error if event loop creation or execution fails.