PhysicalMaterial

Struct PhysicalMaterial 

pub struct PhysicalMaterial {
    pub auto_sync_texture_to_uniforms: bool,
    /* private fields */
}

Fields

auto_sync_texture_to_uniforms: bool

Implementations

Source

impl PhysicalMaterial

pub fn new(color: Vec4) -> PhysicalMaterial

pub fn with_color(self, color: Vec4) -> PhysicalMaterial

Sets the base color (builder).

pub fn with_roughness(self, roughness: f32) -> PhysicalMaterial

Sets the roughness factor (builder).

pub fn with_metalness(self, metalness: f32) -> PhysicalMaterial

Sets the metalness factor (builder).

pub fn with_emissive(self, color: Vec3, intensity: f32) -> PhysicalMaterial

Sets the emissive color and intensity (builder).

pub fn with_opacity(self, opacity: f32) -> PhysicalMaterial

Sets the opacity (builder).

pub fn with_normal_scale(self, scale: Vec2) -> PhysicalMaterial

Sets the normal map scale (builder).

pub fn with_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the color map texture (builder).

pub fn with_normal_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the normal map texture (builder).

pub fn with_roughness_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the roughness map texture (builder).

pub fn with_metalness_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the metalness map texture (builder).

pub fn with_emissive_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the emissive map texture (builder).

pub fn with_ao_map(self, handle: TextureHandle) -> PhysicalMaterial

Sets the AO map texture (builder).

pub fn with_side(self, side: Side) -> PhysicalMaterial

Sets the face culling side (builder).

pub fn with_alpha_mode(self, mode: AlphaMode) -> PhysicalMaterial

Sets the alpha mode (builder).

pub fn with_depth_write(self, enabled: bool) -> PhysicalMaterial

Sets depth write (builder).

pub fn disable_feature(&self, feature: PhysicalFeatures)

pub fn enable_feature(&self, feature: PhysicalFeatures)

pub fn with_clearcoat(self, factor: f32, roughness: f32) -> PhysicalMaterial

pub fn with_sheen(self, color: Vec3, roughness: f32) -> PhysicalMaterial

pub fn with_iridescence( self, intensity: f32, ior: f32, thickness_min: f32, thickness_max: f32, ) -> PhysicalMaterial

pub fn with_anisotropy(self, anisotropy: f32, rotation: f32) -> PhysicalMaterial

pub fn with_transmission( self, transmission: f32, thickness: f32, attenuation_distance: f32, attenuation_color: Vec3, ) -> PhysicalMaterial

pub fn with_dispersion(self, dispersion: f32) -> PhysicalMaterial

pub fn set_sss_id(&self, id: Option<FeatureId>)

pub fn sss_id(&self) -> Option<FeatureId>

pub fn set_ssr_id(&self, id: Option<FeatureId>)

pub fn ssr_id(&self) -> Option<FeatureId>

pub fn with_sss_id(self, id: FeatureId) -> PhysicalMaterial

pub fn with_ssr_id(self, id: FeatureId) -> PhysicalMaterial

Source

impl PhysicalMaterial

pub fn settings_mut(&self) -> SettingsGuard<'_>

pub fn settings(&self) -> MaterialSettings

pub fn set_alpha_mode(&self, mode: AlphaMode)

pub fn alpha_mode(&self) -> AlphaMode

pub fn set_side(&self, side: Side)

Sets the face culling mode (Front/Back/Double).

pub fn side(&self) -> Side

pub fn set_depth_test(&self, depth_test: bool)

Enables or disables depth testing.

pub fn depth_test(&self) -> bool

pub fn set_depth_write(&self, depth_write: bool)

Enables or disables depth writing. For transparent objects, it’s usually recommended to disable this.

pub fn depth_write(&self) -> bool

pub fn uniforms_mut(&self) -> BufferGuard<'_, PhysicalUniforms>

Gets a mutable accessor for all Uniform parameters (for batch modifications). The Guard will automatically mark data as Dirty when it goes out of scope.

pub fn uniforms(&self) -> BufferReadGuard<'_, PhysicalUniforms>

Gets a read-only accessor for all Uniform parameters.

pub fn set_color(&self, value: Vec4)

Base color.

pub fn color(&self) -> Vec4

pub fn set_alpha_test(&self, value: f32)

Alpha test threshold.

pub fn alpha_test(&self) -> f32

pub fn set_roughness(&self, value: f32)

Roughness factor.

pub fn roughness(&self) -> f32

pub fn set_metalness(&self, value: f32)

Metalness factor.

pub fn metalness(&self) -> f32

pub fn set_opacity(&self, value: f32)

Opacity value.

pub fn opacity(&self) -> f32

pub fn set_emissive(&self, value: Vec3)

Emissive color.

pub fn emissive(&self) -> Vec3

pub fn set_emissive_intensity(&self, value: f32)

Emissive intensity.

pub fn emissive_intensity(&self) -> f32

pub fn set_normal_scale(&self, value: Vec2)

Normal map scale.

pub fn normal_scale(&self) -> Vec2

pub fn set_ao_map_intensity(&self, value: f32)

AO map intensity.

pub fn ao_map_intensity(&self) -> f32

pub fn set_ior(&self, value: f32)

Index of Refraction.

pub fn ior(&self) -> f32

pub fn set_specular_color(&self, value: Vec3)

Specular color.

pub fn specular_color(&self) -> Vec3

pub fn set_specular_intensity(&self, value: f32)

Specular intensity.

pub fn specular_intensity(&self) -> f32

pub fn set_clearcoat(&self, value: f32)

Clearcoat factor.

pub fn clearcoat(&self) -> f32

pub fn set_clearcoat_roughness(&self, value: f32)

Clearcoat roughness factor.

pub fn clearcoat_roughness(&self) -> f32

pub fn set_sheen_color(&self, value: Vec3)

The sheen tint. Default is (0, 0, 0), black.

pub fn sheen_color(&self) -> Vec3

pub fn set_sheen_roughness(&self, value: f32)

The sheen roughness. Default is 1.0.

pub fn sheen_roughness(&self) -> f32

pub fn set_iridescence(&self, value: f32)

The intensity of the iridescence layer, simulating RGB color shift based on the angle between the surface and the viewer.

pub fn iridescence(&self) -> f32

pub fn set_iridescence_ior(&self, value: f32)

The strength of the iridescence RGB color shift effect, represented by an index-of-refraction. Default is 1.3.

pub fn iridescence_ior(&self) -> f32

pub fn set_iridescence_thickness_min(&self, value: f32)

The minimum thickness of the thin-film layer given in nanometers. Default is 100 nm.

pub fn iridescence_thickness_min(&self) -> f32

pub fn set_iridescence_thickness_max(&self, value: f32)

The maximum thickness of the thin-film layer given in nanometers. Default is 400 nm.

pub fn iridescence_thickness_max(&self) -> f32

pub fn set_transmission(&self, value: f32)

The transmission factor controlling the amount of light that passes through the surface.

pub fn transmission(&self) -> f32

pub fn set_thickness(&self, value: f32)

The thickness of the object used for subsurface absorption.

pub fn thickness(&self) -> f32

pub fn set_attenuation_color(&self, value: Vec3)

The color that light is attenuated towards as it passes through the material.

pub fn attenuation_color(&self) -> Vec3

pub fn set_attenuation_distance(&self, value: f32)

The distance that light travels through the material before it is absorbed.

pub fn attenuation_distance(&self) -> f32

pub fn set_dispersion(&self, value: f32)

The amount of chromatic dispersion in the transmitted light.

pub fn dispersion(&self) -> f32

pub fn set_map(&self, value: Option<TextureHandle>)

The color map.

pub fn map(&self) -> Option<TextureHandle>

pub fn set_map_transform(&self, transform: TextureTransform)

pub fn configure_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_normal_map(&self, value: Option<TextureHandle>)

The normal map.

pub fn normal_map(&self) -> Option<TextureHandle>

pub fn set_normal_map_transform(&self, transform: TextureTransform)

pub fn configure_normal_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_roughness_map(&self, value: Option<TextureHandle>)

The roughness map.

pub fn roughness_map(&self) -> Option<TextureHandle>

pub fn set_roughness_map_transform(&self, transform: TextureTransform)

pub fn configure_roughness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_metalness_map(&self, value: Option<TextureHandle>)

The metalness map.

pub fn metalness_map(&self) -> Option<TextureHandle>

pub fn set_metalness_map_transform(&self, transform: TextureTransform)

pub fn configure_metalness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_ao_map(&self, value: Option<TextureHandle>)

The AO map.

pub fn ao_map(&self) -> Option<TextureHandle>

pub fn set_ao_map_transform(&self, transform: TextureTransform)

pub fn configure_ao_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_emissive_map(&self, value: Option<TextureHandle>)

The emissive map.

pub fn emissive_map(&self) -> Option<TextureHandle>

pub fn set_emissive_map_transform(&self, transform: TextureTransform)

pub fn configure_emissive_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_specular_map(&self, value: Option<TextureHandle>)

The specular map.

pub fn specular_map(&self) -> Option<TextureHandle>

pub fn set_specular_map_transform(&self, transform: TextureTransform)

pub fn configure_specular_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_specular_intensity_map(&self, value: Option<TextureHandle>)

The specular intensity map.

pub fn specular_intensity_map(&self) -> Option<TextureHandle>

pub fn set_specular_intensity_map_transform(&self, transform: TextureTransform)

pub fn configure_specular_intensity_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_clearcoat_map(&self, value: Option<TextureHandle>)

The clearcoat map.

pub fn clearcoat_map(&self) -> Option<TextureHandle>

pub fn set_clearcoat_map_transform(&self, transform: TextureTransform)

pub fn configure_clearcoat_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_clearcoat_roughness_map(&self, value: Option<TextureHandle>)

The clearcoat roughness map.

pub fn clearcoat_roughness_map(&self) -> Option<TextureHandle>

pub fn set_clearcoat_roughness_map_transform(&self, transform: TextureTransform)

pub fn configure_clearcoat_roughness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_clearcoat_normal_map(&self, value: Option<TextureHandle>)

The clearcoat normal map.

pub fn clearcoat_normal_map(&self) -> Option<TextureHandle>

pub fn set_clearcoat_normal_map_transform(&self, transform: TextureTransform)

pub fn configure_clearcoat_normal_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_sheen_color_map(&self, value: Option<TextureHandle>)

The sheen color map.

pub fn sheen_color_map(&self) -> Option<TextureHandle>

pub fn set_sheen_color_map_transform(&self, transform: TextureTransform)

pub fn configure_sheen_color_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_sheen_roughness_map(&self, value: Option<TextureHandle>)

The sheen roughness map.

pub fn sheen_roughness_map(&self) -> Option<TextureHandle>

pub fn set_sheen_roughness_map_transform(&self, transform: TextureTransform)

pub fn configure_sheen_roughness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_iridescence_map(&self, value: Option<TextureHandle>)

The iridescence map.

pub fn iridescence_map(&self) -> Option<TextureHandle>

pub fn set_iridescence_map_transform(&self, transform: TextureTransform)

pub fn configure_iridescence_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_iridescence_thickness_map(&self, value: Option<TextureHandle>)

The iridescence thickness map.

pub fn iridescence_thickness_map(&self) -> Option<TextureHandle>

pub fn set_iridescence_thickness_map_transform( &self, transform: TextureTransform, )

pub fn configure_iridescence_thickness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_anisotropy_map(&self, value: Option<TextureHandle>)

The anisotropy map.

pub fn anisotropy_map(&self) -> Option<TextureHandle>

pub fn set_anisotropy_map_transform(&self, transform: TextureTransform)

pub fn configure_anisotropy_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_transmission_map(&self, value: Option<TextureHandle>)

The transmission map.

pub fn transmission_map(&self) -> Option<TextureHandle>

pub fn set_transmission_map_transform(&self, transform: TextureTransform)

pub fn configure_transmission_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn set_thickness_map(&self, value: Option<TextureHandle>)

The thickness map.

pub fn thickness_map(&self) -> Option<TextureHandle>

pub fn set_thickness_map_transform(&self, transform: TextureTransform)

pub fn configure_thickness_map<F>(&self, f: F)
where F: FnOnce(&mut TextureSlot),

pub fn flush_texture_transforms(&self) -> bool

Flushes texture transform matrices to Uniforms. Only writes when values actually change, avoiding unnecessary version bumps. Returns whether any data was updated.

pub fn configure<F>(&self, f: F)

pub fn notify_pipeline_dirty(&self)

Manually notifies that the material pipeline needs to be rebuilt.

Note: In most cases, you don’t need to call this method manually, as modifying texture slots through the standard API will automatically track version changes. This method is only for the following special scenarios:

  • After directly modifying pub(crate) fields (e.g., in loader internal code)
  • When you’re certain the material configuration has changed but the version hasn’t been updated