pub struct UnlitMaterial {
pub auto_sync_texture_to_uniforms: bool,
/* private fields */
}Fields
auto_sync_texture_to_uniforms: boolImplementations
Sourceimpl UnlitMaterial
impl UnlitMaterial
pub fn new(color: Vec4) -> UnlitMaterial
Sourcepub fn with_color(self, color: Vec4) -> UnlitMaterial
pub fn with_color(self, color: Vec4) -> UnlitMaterial
Sets the base color (builder).
Sourcepub fn with_opacity(self, opacity: f32) -> UnlitMaterial
pub fn with_opacity(self, opacity: f32) -> UnlitMaterial
Sets the opacity (builder).
Sourcepub fn with_map(self, handle: TextureHandle) -> UnlitMaterial
pub fn with_map(self, handle: TextureHandle) -> UnlitMaterial
Sets the color map texture (builder).
Sourcepub fn with_side(self, side: Side) -> UnlitMaterial
pub fn with_side(self, side: Side) -> UnlitMaterial
Sets the face culling side (builder).
Sourcepub fn with_alpha_mode(self, mode: AlphaMode) -> UnlitMaterial
pub fn with_alpha_mode(self, mode: AlphaMode) -> UnlitMaterial
Sets the alpha mode (builder).
Sourcepub fn with_depth_write(self, enabled: bool) -> UnlitMaterial
pub fn with_depth_write(self, enabled: bool) -> UnlitMaterial
Sets depth write (builder).
Sourceimpl UnlitMaterial
impl UnlitMaterial
pub fn settings_mut(&self) -> SettingsGuard<'_>
pub fn settings(&self) -> MaterialSettings
pub fn set_alpha_mode(&self, mode: AlphaMode)
pub fn alpha_mode(&self) -> AlphaMode
pub fn side(&self) -> Side
Sourcepub fn set_depth_test(&self, depth_test: bool)
pub fn set_depth_test(&self, depth_test: bool)
Enables or disables depth testing.
pub fn depth_test(&self) -> bool
Sourcepub fn set_depth_write(&self, depth_write: bool)
pub fn set_depth_write(&self, depth_write: bool)
Enables or disables depth writing. For transparent objects, it’s usually recommended to disable this.
pub fn depth_write(&self) -> bool
Sourcepub fn uniforms_mut(&self) -> BufferGuard<'_, UnlitUniforms>
pub fn uniforms_mut(&self) -> BufferGuard<'_, UnlitUniforms>
Gets a mutable accessor for all Uniform parameters (for batch modifications). The Guard will automatically mark data as Dirty when it goes out of scope.
Sourcepub fn uniforms(&self) -> BufferReadGuard<'_, UnlitUniforms>
pub fn uniforms(&self) -> BufferReadGuard<'_, UnlitUniforms>
Gets a read-only accessor for all Uniform parameters.
pub fn color(&self) -> Vec4
Sourcepub fn set_opacity(&self, value: f32)
pub fn set_opacity(&self, value: f32)
Opacity value.
pub fn opacity(&self) -> f32
Sourcepub fn set_alpha_test(&self, value: f32)
pub fn set_alpha_test(&self, value: f32)
Alpha test threshold.
pub fn alpha_test(&self) -> f32
Sourcepub fn set_map(&self, value: Option<TextureHandle>)
pub fn set_map(&self, value: Option<TextureHandle>)
The color map.
pub fn map(&self) -> Option<TextureHandle>
pub fn set_map_transform(&self, transform: TextureTransform)
pub fn configure_map<F>(&self, f: F)where
F: FnOnce(&mut TextureSlot),
Sourcepub fn flush_texture_transforms(&self) -> bool
pub fn flush_texture_transforms(&self) -> bool
Flushes texture transform matrices to Uniforms. Only writes when values actually change, avoiding unnecessary version bumps. Returns whether any data was updated.
pub fn configure<F>(&self, f: F)where
F: FnOnce(&UnlitUniforms),
Sourcepub fn notify_pipeline_dirty(&self)
pub fn notify_pipeline_dirty(&self)
Manually notifies that the material pipeline needs to be rebuilt.
Note: In most cases, you don’t need to call this method manually, as modifying texture slots through the standard API will automatically track version changes. This method is only for the following special scenarios:
- After directly modifying
pub(crate)fields (e.g., in loader internal code) - When you’re certain the material configuration has changed but the version hasn’t been updated